@@ -297,18 +297,18 @@ class AddShows(Home):
         Fetches data from IMDB to show a list of popular shows.
         """
         t = PageTemplate(rh=self, filename="addShows_popularShows.mako")
-        e = None
-
         try:
             popular_shows = imdb_popular.fetch_popular_shows()
-        except Exception as e:
-            logger.warning("Could not get popular shows: {0}".format(str(e)))
+            imdb_exception = None
+        except Exception as error:
+            logger.warning("Could not get popular shows: {0}".format(str(error)))
+            logger.debug(traceback.format_exc())
             popular_shows = None
+            imdb_exception = error
 
         return t.render(title=_("Popular Shows"), header=_("Popular Shows"),
-                        popular_shows=popular_shows, imdb_exception=e,
-                        topmenu="home",
-                        controller="addShows", action="popularShows")
+                        popular_shows=popular_shows, imdb_exception=imdb_exception,
+                        topmenu="home", controller="addShows", action="popularShows")
 
     def favoriteShows(self):
         """
